@@ -13,19 +13,25 @@ import matplotlib.ticker as mtick
 import numpy as np
 import pandas as pd
 
+from scipy import stats
 from sklearn.exceptions import NotFittedError
 
+from ..formatting import dataframe_to_string
+from .auto_monotonic import type_of_monotonic_trend
 from .metrics import bayesian_probability
 from .metrics import binning_quality_score
 from .metrics import chi2_cramer_v
 from .metrics import chi2_cramer_v_multi
+from .metrics import continuous_binning_quality_score
 from .metrics import frequentist_pvalue
 from .metrics import hhi
 from .metrics import gini
+from .metrics import hellinger
 from .metrics import jeffrey
 from .metrics import jensen_shannon
 from .metrics import jensen_shannon_multivariate
 from .metrics import multiclass_binning_quality_score
+from .metrics import triangular
 
 
 COLORS_RGB = [
@@ -172,22 +178,28 @@ def multiclass_bin_info(solution, n_classes, n_event, n_event_missing,
     return np.array(n_ev).astype(np.int)
 
 
-def continuous_bin_info(solution, n_records, sums, min_target, max_target,
-                        n_zeros, n_records_missing, sum_missing,
-                        min_target_missing, max_target_missing,
+def nstd(s, ss, records):
+    return np.sqrt(ss / records - (s / records) ** 2)
+
+
+def continuous_bin_info(solution, n_records, sums, ssums, stds, min_target,
+                        max_target, n_zeros, n_records_missing, sum_missing,
+                        std_missing,  min_target_missing, max_target_missing,
                         n_zeros_missing, n_records_special, sum_special,
-                        min_target_special, max_target_special,
+                        std_special, min_target_special, max_target_special,
                         n_zeros_special, n_records_cat_others, sum_cat_others,
-                        min_target_others, max_target_others, n_zeros_others,
-                        cat_others):
+                        std_cat_others, min_target_others, max_target_others,
+                        n_zeros_others, cat_others):
     r = []
     s = []
+    st = []
     z = []
     min_t = []
     max_t = []
     min_t
     accum_r = 0
     accum_s = 0
+    accum_ss = 0
     accum_z = 0
     accum_min_t = np.inf
     accum_max_t = -np.inf
@@ -195,17 +207,22 @@ def continuous_bin_info(solution, n_records, sums, min_target, max_target,
         if selected:
             r.append(n_records[i] + accum_r)
             s.append(sums[i] + accum_s)
+            st.append(nstd(sums[i] + accum_s, ssums[i] + accum_ss,
+                           n_records[i] + accum_r))
             z.append(n_zeros[i] + accum_z)
             min_t.append(min(accum_min_t, min_target[i]))
             max_t.append(max(accum_max_t, max_target[i]))
+
             accum_r = 0
             accum_s = 0
+            accum_ss = 0
             accum_z = 0
             accum_min_t = np.inf
             accum_max_t = -np.inf
         else:
             accum_r += n_records[i]
             accum_s += sums[i]
+            accum_ss += ssums[i]
             accum_z += n_zeros[i]
             accum_min_t = min(accum_min_t, min_target[i])
             accum_max_t = max(accum_max_t, max_target[i])
@@ -213,6 +230,7 @@ def continuous_bin_info(solution, n_records, sums, min_target, max_target,
     if not len(solution):
         r.append(n_records)
         s.append(sums)
+        st.append(stds)
         z.append(n_zeros)
         min_t.append(min_target)
         max_t.append(max_target)
@@ -220,25 +238,28 @@ def continuous_bin_info(solution, n_records, sums, min_target, max_target,
     if len(cat_others):
         r.append(n_records_cat_others)
         s.append(sum_cat_others)
+        st.append(std_cat_others)
         z.append(n_zeros_others)
         min_t.append(min_target_others)
         max_t.append(max_target_others)
 
     r.append(n_records_special)
     s.append(sum_special)
+    st.append(std_special)
     z.append(n_zeros_special)
     min_t.append(min_target_special)
     max_t.append(max_target_special)
 
     r.append(n_records_missing)
     s.append(sum_missing)
+    st.append(std_missing)
     z.append(n_zeros_missing)
     min_t.append(min_target_missing)
     max_t.append(max_target_special)
 
     return (np.array(r).astype(np.int64), np.array(s).astype(np.float),
-            np.array(min_t).astype(np.float), np.array(max_t).astype(np.float),
-            np.array(z).astype(np.int64))
+            np.array(st).astype(np.float), np.array(min_t).astype(np.float),
+            np.array(max_t).astype(np.float), np.array(z).astype(np.int64))
 
 
 def _check_build_parameters(show_digits, add_totals):
@@ -289,6 +310,12 @@ class BinningTable:
     n_event : numpy.ndarray
         Number of events.
 
+    min_x : float or None (default=None)
+        Mininum value of x.
+
+    max_x : float or None (default=None)
+        Maxinum value of x.
+
     categories : list, numpy.ndarray or None, optional (default=None)
         List of categories.
 
@@ -304,14 +331,17 @@ class BinningTable:
     preferable to use the class returned by the property ``binning_table``
     available in all optimal binning classes.
     """
-    def __init__(self, name, dtype, splits, n_nonevent, n_event,
-                 categories=None, cat_others=None, user_splits=None):
+    def __init__(self, name, dtype, splits, n_nonevent, n_event, min_x=None,
+                 max_x=None, categories=None, cat_others=None,
+                 user_splits=None):
 
         self.name = name
         self.dtype = dtype
         self.splits = splits
         self.n_nonevent = n_nonevent
         self.n_event = n_event
+        self.min_x = min_x
+        self.max_x = max_x
         self.categories = categories
         self.cat_others = cat_others if cat_others is not None else []
         self.user_splits = user_splits
@@ -325,6 +355,7 @@ class BinningTable:
         self._js = None
         self._gini = None
         self._quality_score = None
+        self._ks = None
 
         self._is_built = False
         self._is_analyzed = False
@@ -384,6 +415,11 @@ class BinningTable:
 
         self._iv = t_iv
         self._js = t_js
+        self._hellinger = hellinger(p_ev, p_nev, return_sum=True)
+        self._triangular = triangular(p_ev, p_nev, return_sum=True)
+
+        # Compute KS
+        self._ks = np.abs(p_event.cumsum() - p_nonevent.cumsum()).max()
 
         # Compute HHI
         self._hhi = hhi(p_records)
@@ -425,7 +461,7 @@ class BinningTable:
         return df
 
     def plot(self, metric="woe", add_special=True, add_missing=True,
-             savefig=None):
+             style="bin", savefig=None):
         """Plot the binning table.
 
         Visualize the non-event and event count, and the Weight of Evidence or
@@ -443,6 +479,11 @@ class BinningTable:
         add_missing : bool (default=True)
             Whether to add the special values bin.
 
+        style: str, optional (default="bin")
+            Plot style. style="bin" shows the standard binning plot. If
+            style="actual", show the plot with the actual scale, i.e, actual
+            bin widths.
+
         savefig : str or None (default=None)
             Path to save the plot figure.
         """
@@ -460,38 +501,21 @@ class BinningTable:
             raise TypeError("add_missing must be a boolean; got {}."
                             .format(add_missing))
 
-        n_bins = len(self._n_records)
-        n_metric = n_bins - 2
+        if style not in ("bin", "actual"):
+            raise ValueError('Invalid value for style. Allowed string '
+                             'values are "bin" and "actual".')
 
-        if len(self.cat_others):
-            n_metric -= 1
+        if style == "actual":
+            if add_special or add_missing:
+                raise ValueError('If style="actual", add_special and '
+                                 'add_missing must be set to False.')
 
-        _n_event = list(self.n_event)
-        _n_nonevent = list(self.n_nonevent)
+            elif self.dtype == "categorical":
+                raise ValueError('If style="actual", dtype must be numerical.')
 
-        if not add_special:
-            _n_event.pop(-2)
-            _n_nonevent.pop(-2)
-            n_bins -= 1
-
-        if not add_missing:
-            _n_event.pop(-1)
-            _n_nonevent.pop(-1)
-            n_bins -= 1
-
-        fig, ax1 = plt.subplots()
-
-        p2 = ax1.bar(range(n_bins), _n_event, color="tab:red")
-        p1 = ax1.bar(range(n_bins), _n_nonevent, color="tab:blue",
-                     bottom=_n_event)
-
-        handles = [p1[0], p2[0]]
-        labels = ['Non-event', 'Event']
-
-        ax1.set_xlabel("Bin ID", fontsize=12)
-        ax1.set_ylabel("Bin count", fontsize=13)
-
-        ax2 = ax1.twinx()
+            elif self.min_x is None or self.max_x is None:
+                raise ValueError('If style="actual", min_x and max_x must be '
+                                 'provided.')
 
         if metric == "woe":
             metric_values = self._woe
@@ -500,59 +524,133 @@ class BinningTable:
             metric_values = self._event_rate
             metric_label = "Event rate"
 
-        ax2.plot(range(n_metric), metric_values[:n_metric], linestyle="solid",
-                 marker="o", color="black")
+        fig, ax1 = plt.subplots()
+
+        if style == "bin":
+            n_bins = len(self._n_records)
+            n_metric = n_bins - 2
+
+            if len(self.cat_others):
+                n_metric -= 1
+
+            _n_event = list(self.n_event)
+            _n_nonevent = list(self.n_nonevent)
+
+            if not add_special:
+                _n_event.pop(-2)
+                _n_nonevent.pop(-2)
+                n_bins -= 1
+
+            if not add_missing:
+                _n_event.pop(-1)
+                _n_nonevent.pop(-1)
+                n_bins -= 1
+
+            p2 = ax1.bar(range(n_bins), _n_event, color="tab:red")
+            p1 = ax1.bar(range(n_bins), _n_nonevent, color="tab:blue",
+                         bottom=_n_event)
+
+            handles = [p1[0], p2[0]]
+            labels = ['Non-event', 'Event']
+
+            ax1.set_xlabel("Bin ID", fontsize=12)
+            ax1.set_ylabel("Bin count", fontsize=13)
+
+            ax2 = ax1.twinx()
+
+            ax2.plot(range(n_metric), metric_values[:n_metric],
+                     linestyle="solid", marker="o", color="black")
+
+            # Positions special and missing bars
+            if add_special:
+                pos_special = n_metric
+                if add_missing:
+                    pos_missing = n_metric + 1
+            elif add_missing:
+                pos_missing = n_metric
+
+            # Add points for others (optional), special and missing bin
+            if len(self.cat_others):
+                pos_others = n_metric
+                pos_special += 1
+                pos_missing += 1
+
+                p1[pos_others].set_alpha(0.5)
+                p2[pos_others].set_alpha(0.5)
+
+                ax2.plot(pos_others, metric_values[pos_others], marker="o",
+                         color="black")
+
+            if add_special:
+                p1[pos_special].set_hatch("/")
+                p2[pos_special].set_hatch("/")
+                handle_special = mpatches.Patch(hatch="/", alpha=0.1)
+                label_special = "Bin special"
+
+                ax2.plot(pos_special, metric_values[pos_special], marker="o",
+                         color="black")
 
-        # Positions special and missing bars
-        if add_special:
-            pos_special = n_metric
             if add_missing:
-                pos_missing = n_metric + 1
-        elif add_missing:
-            pos_missing = n_metric
+                p1[pos_missing].set_hatch("\\")
+                p2[pos_missing].set_hatch("\\")
+                handle_missing = mpatches.Patch(hatch="\\", alpha=0.1)
+                label_missing = "Bin missing"
 
-        # Add points for others (optional), special and missing bin
-        if len(self.cat_others):
-            pos_others = n_metric
-            pos_special += 1
-            pos_missing += 1
+                ax2.plot(pos_missing, metric_values[pos_missing], marker="o",
+                         color="black")
 
-            p1[pos_others].set_alpha(0.5)
-            p2[pos_others].set_alpha(0.5)
+            if add_special and add_missing:
+                handles.extend([handle_special, handle_missing])
+                labels.extend([label_special, label_missing])
+            elif add_special:
+                handles.extend([handle_special])
+                labels.extend([label_special])
+            elif add_missing:
+                handles.extend([handle_missing])
+                labels.extend([label_missing])
 
-            ax2.plot(pos_others, metric_values[pos_others], marker="o",
-                     color="black")
+            ax2.set_ylabel(metric_label, fontsize=13)
+            ax2.xaxis.set_major_locator(mtick.MultipleLocator(1))
 
-        if add_special:
-            p1[pos_special].set_hatch("/")
-            p2[pos_special].set_hatch("/")
-            handle_special = mpatches.Patch(hatch="/", alpha=0.1)
-            label_special = "Bin special"
+        elif style == "actual":
+            _n_nonevent = self.n_nonevent[:-2]
+            _n_event = self.n_event[:-2]
 
-            ax2.plot(pos_special, metric_values[pos_special], marker="o",
-                     color="black")
+            n_splits = len(self.splits)
 
-        if add_missing:
-            p1[pos_missing].set_hatch("\\")
-            p2[pos_missing].set_hatch("\\")
-            handle_missing = mpatches.Patch(hatch="\\", alpha=0.1)
-            label_missing = "Bin missing"
+            y_pos = np.empty(n_splits + 2)
+            y_pos[0] = self.min_x
+            y_pos[1:-1] = self.splits
+            y_pos[-1] = self.max_x
 
-            ax2.plot(pos_missing, metric_values[pos_missing], marker="o",
-                     color="black")
+            width = y_pos[1:] - y_pos[:-1]
+            y_pos2 = y_pos[:-1]
 
-        if add_special and add_missing:
-            handles.extend([handle_special, handle_missing])
-            labels.extend([label_special, label_missing])
-        elif add_special:
-            handles.extend([handle_special])
-            labels.extend([label_special])
-        elif add_missing:
-            handles.extend([handle_missing])
-            labels.extend([label_missing])
+            p2 = ax1.bar(y_pos2, _n_event, width, color="tab:red",
+                         align="edge")
+            p1 = ax1.bar(y_pos2, _n_nonevent, width, color="tab:blue",
+                         bottom=_n_event, align="edge")
 
-        ax2.set_ylabel(metric_label, fontsize=13)
-        ax2.xaxis.set_major_locator(mtick.MultipleLocator(1))
+            handles = [p1[0], p2[0]]
+            labels = ['Non-event', 'Event']
+
+            ax1.set_xlabel("x", fontsize=12)
+            ax1.set_ylabel("Bin count", fontsize=13)
+
+            ax2 = ax1.twinx()
+
+            for i in range(n_splits + 1):
+                ax2.plot([y_pos[i], y_pos[i+1]], [metric_values[i]] * 2,
+                         linestyle="solid", color="black")
+
+            ax2.plot(width / 2 + y_pos2, metric_values[:-2],
+                     linewidth=0.75, marker="o", color="black")
+
+            for split in self.splits:
+                ax2.axvline(x=split, color="black", linestyle="--",
+                            linewidth=0.9)
+
+            ax2.set_ylabel(metric_label, fontsize=13)
 
         plt.title(self.name, fontsize=14)
         plt.legend(handles, labels, loc="upper center",
@@ -589,8 +687,6 @@ class BinningTable:
             consecutive bins to compute the probability of the event rate of
             bin A being greater than the event rate of bin B.
 
-        Parameters
-        ----------
         print_output : bool (default=True)
             Whether to print analysis information.
 
@@ -642,10 +738,6 @@ class BinningTable:
             t_statistics.append(t_statistic)
             p_values.append(p_value)
 
-        # Quality score
-        self._quality_score = binning_quality_score(self._iv, p_values,
-                                                    self._hhi_norm)
-
         df_tests = pd.DataFrame({
                 "Bin A": np.arange(n_metric-1),
                 "Bin B": np.arange(n_metric-1) + 1,
@@ -658,12 +750,18 @@ class BinningTable:
         if pvalue_test == "fisher":
             df_tests.rename(columns={"t-statistic": "odd ratio"}, inplace=True)
 
-        tab = "    "
+        tab = 4
         if len(df_tests):
-            df_tests_string = tab + df_tests.to_string(index=False).replace(
-                "\n", "\n"+tab)
+            df_tests_string = dataframe_to_string(df_tests, tab)
         else:
-            df_tests_string = tab+"None"
+            df_tests_string = " " * tab + "None"
+
+        # Quality score
+        self._quality_score = binning_quality_score(self._iv, p_values,
+                                                    self._hhi_norm)
+
+        # Monotonic trend
+        type_mono = type_of_monotonic_trend(self._event_rate[:-2])
 
         report = (
             "---------------------------------------------\n"
@@ -675,14 +773,20 @@ class BinningTable:
             "    Gini index          {:>15.8f}\n"
             "    IV (Jeffrey)        {:>15.8f}\n"
             "    JS (Jensen-Shannon) {:>15.8f}\n"
+            "    Hellinger           {:>15.8f}\n"
+            "    Triangular          {:>15.8f}\n"
+            "    KS                  {:>15.8f}\n"
             "    HHI                 {:>15.8f}\n"
             "    HHI (normalized)    {:>15.8f}\n"
             "    Cramer's V          {:>15.8f}\n"
             "    Quality score       {:>15.8f}\n"
             "\n"
+            "  Monotonic trend       {:>15}\n"
+            "\n"
             "  Significance tests\n\n{}\n"
-            ).format(self._gini, self._iv, self._js, self._hhi, self._hhi_norm,
-                     cramer_v, self._quality_score, df_tests_string)
+            ).format(self._gini, self._iv, self._js, self._hellinger,
+                     self._triangular, self._ks, self._hhi, self._hhi_norm,
+                     cramer_v, self._quality_score, type_mono, df_tests_string)
 
         if print_output:
             print(report)
@@ -733,6 +837,42 @@ class BinningTable:
 
         return self._js
 
+    @property
+    def hellinger(self):
+        """The Hellinger divergence.
+
+        Returns
+        -------
+        hellinger : float
+        """
+        _check_is_built(self)
+
+        return self._hellinger
+
+    @property
+    def triangular(self):
+        """The triangular divergence.
+
+        Returns
+        -------
+        triangular : float
+        """
+        _check_is_built(self)
+
+        return self._triangular
+
+    @property
+    def ks(self):
+        """The Kolmogorov-Smirnov statistic.
+
+        Returns
+        -------
+        ks : float
+        """
+        _check_is_built(self)
+
+        return self._ks
+
     @property
     def quality_score(self):
         """The quality score (QS).
@@ -1021,10 +1161,6 @@ class MulticlassBinningTable:
             t_statistics.append(t_statistic)
             p_values.append(p_value)
 
-        # Quality score
-        self._quality_score = multiclass_binning_quality_score(
-            self._js, len(self.classes), p_values, self._hhi_norm)
-
         df_tests = pd.DataFrame({
                 "Bin A": np.arange(n_metric-1),
                 "Bin B": np.arange(n_metric-1) + 1,
@@ -1032,12 +1168,23 @@ class MulticlassBinningTable:
                 "p-value": p_values
             })
 
-        tab = "    "
+        tab = 4
         if len(df_tests):
-            df_tests_string = tab + df_tests.to_string(index=False).replace(
-                "\n", "\n"+tab)
+            df_tests_string = dataframe_to_string(df_tests, tab)
         else:
-            df_tests_string = tab+"None"
+            df_tests_string = " " * tab + "None"
+
+        # Quality score
+        self._quality_score = multiclass_binning_quality_score(
+            self._js, len(self.classes), p_values, self._hhi_norm)
+
+        # Monotonic trend
+        mono_string = "    Class {:>2}            {:>15}\n"
+        monotonic_string = ""
+
+        for i in range(len(self.classes)):
+            type_mono = type_of_monotonic_trend(self._event_rate[:-2, i])
+            monotonic_string += mono_string.format(i, type_mono)
 
         report = (
             "-------------------------------------------------\n"
@@ -1052,9 +1199,11 @@ class MulticlassBinningTable:
             "    Cramer's V          {:>15.8f}\n"
             "    Quality score       {:>15.8f}\n"
             "\n"
+            "  Monotonic trend\n\n{}"
+            "\n"
             "  Significance tests\n\n{}\n"
             ).format(self._js, self._hhi, self._hhi_norm, cramer_v,
-                     self._quality_score, df_tests_string)
+                     self._quality_score, monotonic_string, df_tests_string)
 
         if print_output:
             print(report)
@@ -1114,6 +1263,9 @@ class ContinuousBinningTable:
     sums : numpy.ndarray
         Target sums.
 
+    stds : numpy.ndarray
+        Target stds.
+
     min_target : numpy.ndarray
         Target mininum values.
 
@@ -1123,6 +1275,12 @@ class ContinuousBinningTable:
     n_zeros : numpy.ndarray
         Number of zeros.
 
+    min_x : float or None (default=None)
+        Mininum value of x.
+
+    max_x : float or None (default=None)
+        Maxinum value of x.
+
     categories : list, numpy.ndarray or None, optional (default=None)
         List of categories.
 
@@ -1138,23 +1296,29 @@ class ContinuousBinningTable:
     preferable to use the class returned by the property ``binning_table``
     available in all optimal binning classes.
     """
-    def __init__(self, name, dtype, splits, n_records, sums, min_target,
-                 max_target, n_zeros, categories=None, cat_others=None,
-                 user_splits=None):
+    def __init__(self, name, dtype, splits, n_records, sums, stds, min_target,
+                 max_target, n_zeros, min_x=None, max_x=None, categories=None,
+                 cat_others=None, user_splits=None):
 
         self.name = name
         self.dtype = dtype
         self.splits = splits
         self.n_records = n_records
         self.sums = sums
+        self.stds = stds
         self.min_target = min_target
         self.max_target = max_target
         self.n_zeros = n_zeros
+        self.min_x = min_x
+        self.max_x = max_x
         self.categories = categories
         self.cat_others = cat_others if cat_others is not None else []
         self.user_splits = user_splits
 
         self._mean = None
+        self._iv = None
+        self._hhi = None
+        self._hhi_norm = None
 
         self._is_built = False
 
@@ -1187,10 +1351,17 @@ class ContinuousBinningTable:
         if self.n_records[-1] > 0:
             self._mean[-1] = 0
 
+        # Compute divergence measure (continuous adaptation)
         woe = self._mean - t_mean
         iv = np.absolute(woe) * p_records
         t_iv = iv.sum()
 
+        self._iv = t_iv
+
+        # Compute HHI
+        self._hhi = hhi(p_records)
+        self._hhi_norm = hhi(p_records, normalized=True)
+
         if self.dtype == "numerical":
             bins = np.concatenate([[-np.inf], self.splits, [np.inf]])
             bin_str = bin_str_format(bins, show_digits)
@@ -1205,6 +1376,7 @@ class ContinuousBinningTable:
             "Count": self.n_records,
             "Count (%)": p_records,
             "Sum": self.sums,
+            "Std": self.stds,
             "Mean": self._mean,
             "Min": self.min_target,
             "Max": self.max_target,
@@ -1214,10 +1386,10 @@ class ContinuousBinningTable:
             })
 
         if add_totals:
-            t_min = np.min(self.min_target)
-            t_max = np.max(self.max_target)
+            t_min = np.nanmin(self.min_target)
+            t_max = np.nanmax(self.max_target)
             t_n_zeros = self.n_zeros.sum()
-            totals = ["", t_n_records, 1, t_sum, t_mean, t_min, t_max,
+            totals = ["", t_n_records, 1, t_sum, "", t_mean, t_min, t_max,
                       t_n_zeros, "", t_iv]
             df.loc["Totals"] = totals
 
@@ -1225,7 +1397,8 @@ class ContinuousBinningTable:
 
         return df
 
-    def plot(self, add_special=True, add_missing=True, savefig=None):
+    def plot(self, add_special=True, add_missing=True, style="bin",
+             savefig=None):
         """Plot the binning table.
 
         Visualize records count and mean values.
@@ -1238,6 +1411,11 @@ class ContinuousBinningTable:
         add_missing : bool (default=True)
             Whether to add the special values bin.
 
+        style: str, optional (default="bin")
+            Plot style. style="bin" shows the standard binning plot. If
+            style="actual", show the plot with the actual scale, i.e, actual
+            bin widths.
+
         savefig : str or None (default=None)
             Path to save the plot figure.
         """
@@ -1251,90 +1429,145 @@ class ContinuousBinningTable:
             raise TypeError("add_missing must be a boolean; got {}."
                             .format(add_missing))
 
-        n_bins = len(self.n_records)
-        n_metric = n_bins - 2
+        if style not in ("bin", "actual"):
+            raise ValueError('Invalid value for style. Allowed string '
+                             'values are "bin" and "actual".')
 
-        if len(self.cat_others):
-            n_metric -= 1
+        if style == "actual":
+            if add_special or add_missing:
+                raise ValueError('If style="actual", add_special and '
+                                 'add_missing must be set to False.')
 
-        _n_records = list(self.n_records)
+            elif self.dtype == "categorical":
+                raise ValueError('If style="actual", dtype must be numerical.')
 
-        if not add_special:
-            _n_records.pop(-2)
-            n_bins -= 1
-
-        if not add_missing:
-            _n_records.pop(-1)
-            n_bins -= 1
-
-        fig, ax1 = plt.subplots()
-
-        p1 = ax1.bar(range(n_bins), _n_records, color="tab:blue")
-
-        handles = [p1[0]]
-        labels = ['Count']
-
-        ax1.set_xlabel("Bin ID", fontsize=12)
-        ax1.set_ylabel("Bin count", fontsize=13)
-
-        ax2 = ax1.twinx()
+            elif self.min_x is None or self.max_x is None:
+                raise ValueError('If style="actual", min_x and max_x must be '
+                                 'provided.')
 
         metric_values = self._mean
         metric_label = "Mean"
 
-        ax2.plot(range(n_metric), metric_values[:n_metric], linestyle="solid",
-                 marker="o", color="black")
+        fig, ax1 = plt.subplots()
 
-        # Positions special and missing bars
-        pos_special = 0
-        pos_missing = 0
+        if style == "bin":
+            n_bins = len(self.n_records)
+            n_metric = n_bins - 2
+
+            if len(self.cat_others):
+                n_metric -= 1
+
+            _n_records = list(self.n_records)
+
+            if not add_special:
+                _n_records.pop(-2)
+                n_bins -= 1
+
+            if not add_missing:
+                _n_records.pop(-1)
+                n_bins -= 1
+
+            p1 = ax1.bar(range(n_bins), _n_records, color="tab:blue")
+
+            handles = [p1[0]]
+            labels = ['Count']
+
+            ax1.set_xlabel("Bin ID", fontsize=12)
+            ax1.set_ylabel("Bin count", fontsize=13)
+
+            ax2 = ax1.twinx()
+
+            ax2.plot(range(n_metric), metric_values[:n_metric],
+                     linestyle="solid", marker="o", color="black")
+
+            # Positions special and missing bars
+            pos_special = 0
+            pos_missing = 0
+
+            if add_special:
+                pos_special = n_metric
+                if add_missing:
+                    pos_missing = n_metric + 1
+            elif add_missing:
+                pos_missing = n_metric
+
+            # Add points for others (optional), special and missing bin
+            if len(self.cat_others):
+                pos_others = n_metric
+                pos_special += 1
+                pos_missing += 1
+
+                p1[pos_others].set_alpha(0.5)
+
+                ax2.plot(pos_others, metric_values[pos_others], marker="o",
+                         color="black")
+
+            if add_special:
+                p1[pos_special].set_hatch("/")
+                handle_special = mpatches.Patch(hatch="/", alpha=0.1)
+                label_special = "Bin special"
+
+                ax2.plot(pos_special, metric_values[pos_special], marker="o",
+                         color="black")
 
-        if add_special:
-            pos_special = n_metric
             if add_missing:
-                pos_missing = n_metric + 1
-        elif add_missing:
-            pos_missing = n_metric
+                p1[pos_missing].set_hatch("\\")
+                handle_missing = mpatches.Patch(hatch="\\", alpha=0.1)
+                label_missing = "Bin missing"
 
-        # Add points for others (optional), special and missing bin
-        if len(self.cat_others):
-            pos_others = n_metric
-            pos_special += 1
-            pos_missing += 1
+                ax2.plot(pos_missing, metric_values[pos_missing], marker="o",
+                         color="black")
 
-            p1[pos_others].set_alpha(0.5)
+            if add_special and add_missing:
+                handles.extend([handle_special, handle_missing])
+                labels.extend([label_special, label_missing])
+            elif add_special:
+                handles.extend([handle_special])
+                labels.extend([label_special])
+            elif add_missing:
+                handles.extend([handle_missing])
+                labels.extend([label_missing])
 
-            ax2.plot(pos_others, metric_values[pos_others], marker="o",
-                     color="black")
+            ax2.set_ylabel(metric_label, fontsize=13)
+            ax2.xaxis.set_major_locator(mtick.MultipleLocator(1))
 
-        if add_special:
-            p1[pos_special].set_hatch("/")
-            handle_special = mpatches.Patch(hatch="/", alpha=0.1)
-            label_special = "Bin special"
+        elif style == "actual":
+            _n_records = self.n_records[:-2]
 
-            ax2.plot(pos_special, metric_values[pos_special], marker="o",
-                     color="black")
+            n_splits = len(self.splits)
 
-        if add_missing:
-            p1[pos_missing].set_hatch("\\")
-            handle_missing = mpatches.Patch(hatch="\\", alpha=0.1)
-            label_missing = "Bin missing"
+            y_pos = np.empty(n_splits + 2)
+            y_pos[0] = self.min_x
+            y_pos[1:-1] = self.splits
+            y_pos[-1] = self.max_x
 
-            ax2.plot(pos_missing, metric_values[pos_missing], marker="o",
-                     color="black")
+            width = y_pos[1:] - y_pos[:-1]
+            y_pos2 = y_pos[:-1]
 
-        if add_special and add_missing:
-            handles.extend([handle_special, handle_missing])
-            labels.extend([label_special, label_missing])
-        elif add_special:
-            handles.extend([handle_special])
-            labels.extend([label_special])
-        elif add_missing:
-            handles.extend([handle_missing])
-            labels.extend([label_missing])
+            p1 = ax1.bar(y_pos2, _n_records, width, color="tab:blue",
+                         align="edge")
 
-        ax2.set_ylabel(metric_label, fontsize=13)
-        ax2.xaxis.set_major_locator(mtick.MultipleLocator(1))
+            handles = [p1[0]]
+            labels = ['Count']
+
+            ax1.set_xlabel("x", fontsize=12)
+            ax1.set_ylabel("Bin count", fontsize=13)
+            ax1.tick_params(axis='x', labelrotation=45)
+
+            ax2 = ax1.twinx()
+
+            for i in range(n_splits + 1):
+                ax2.plot([y_pos[i], y_pos[i+1]], [metric_values[i]] * 2,
+                         linestyle="solid", color="black")
+
+            ax2.plot(width / 2 + y_pos2, metric_values[:-2],
+                     linewidth=0.75, marker="o", color="black")
+
+            for split in self.splits:
+                ax2.axvline(x=split, color="black", linestyle="--",
+                            linewidth=0.9)
+
+            ax2.set_ylabel(metric_label, fontsize=13)
 
         plt.title(self.name, fontsize=14)
         plt.legend(handles, labels, loc="upper center",
@@ -1348,3 +1581,123 @@ class ContinuousBinningTable:
                                 .format(savefig))
             plt.savefig(savefig)
             plt.close()
+
+    def analysis(self, print_output=True):
+        r"""Binning table analysis.
+
+        Statistical analysis of the binning table, computing the Information
+        Value (IV) and Herfindahl-Hirschman Index (HHI).
+
+        Parameters
+        ----------
+        print_output : bool (default=True)
+            Whether to print analysis information.
+
+        Notes
+        -----
+        The IV for a continuous target is computed as follows:
+
+        .. math::
+
+            IV = \sum_{i=1}^n |U_i - \mu| \frac{r_i}{r_T},
+
+        where :math:`U_i` is the target mean value for each bin, :math:`\mu` is
+        the total target mean, :math:`r_i` is the number of records for each
+        bin, and :math:`r_T` is the total number of records.
+        """
+        _check_is_built(self)
+
+        # Significance tests
+        n_bins = len(self.n_records)
+        n_metric = n_bins - 2
+
+        if len(self.cat_others):
+            n_metric -= 1
+
+        n_records = self.n_records[:n_metric]
+        mean = self._mean[:n_metric]
+        std = self.stds[:n_metric]
+
+        t_statistics = []
+        p_values = []
+
+        for i in range(n_metric-1):
+            u, u2 = mean[i], mean[i+1]
+            s, s2 = std[i], std[i+1]
+            r, r2 = n_records[i], n_records[i+1]
+
+            t_statistic, p_value = stats.ttest_ind_from_stats(
+                u, s, r, u2, s2, r2, False)
+
+            t_statistics.append(t_statistic)
+            p_values.append(p_value)
+
+        df_tests = pd.DataFrame({
+                "Bin A": np.arange(n_metric-1),
+                "Bin B": np.arange(n_metric-1) + 1,
+                "t-statistic": t_statistics,
+                "p-value": p_values
+            })
+
+        tab = 4
+        if len(df_tests):
+            df_tests_string = dataframe_to_string(df_tests, tab)
+        else:
+            df_tests_string = " " * tab + "None"
+
+        # Quality score
+        self._quality_score = continuous_binning_quality_score(
+            p_values, self._hhi_norm)
+
+        # Monotonic trend
+        type_mono = type_of_monotonic_trend(self._mean[:-2])
+
+        report = (
+            "-------------------------------------------------\n"
+            "OptimalBinning: Continuous Binning Table Analysis\n"
+            "-------------------------------------------------\n"
+            "\n"
+            "  General metrics"
+            "\n\n"
+            "    IV                  {:>15.8f}\n"
+            "    HHI                 {:>15.8f}\n"
+            "    HHI (normalized)    {:>15.8f}\n"
+            "    Quality score       {:>15.8f}\n"
+            "\n"
+            "  Monotonic trend       {:>15}\n"
+            "\n"
+            "  Significance tests\n\n{}\n"
+            ).format(self._iv, self._hhi, self._hhi_norm, self._quality_score,
+                     type_mono, df_tests_string)
+
+        if print_output:
+            print(report)
+
+    @property
+    def iv(self):
+        """The Information Value (IV).
+
+        The IV ranges from 0 to Infinity.
+
+        Returns
+        -------
+        iv : float
+        """
+        _check_is_built(self)
+
+        return self._iv
+
+    @property
+    def quality_score(self):
+        """The quality score (QS).
+
+        The QS is a rating of the quality and discriminatory power of a
+        variable. The QS ranges from 0 to 1.
+
+        Returns
+        -------
+        quality_score : float
+        """
+        _check_is_analyzed(self)
+
+        return self._quality_score
